@@ -42,6 +42,7 @@
 /**
  * @file
  */
+
 #include <assert.h>
 #include <string.h>
 #include <stdio.h>
@@ -50,38 +51,15 @@
 #include "test_rfc5444_interop.h"
 
 static uint8_t _binary[] = {
-    0x0c, 0x00, 0x0c, 0x00, 0x02, 0x01, 0x00, 0x01, 0x03, 0x00, 0x06, 0x00,
-    0x00, 0x02, 0xf3, 0x00, 0x0e, 0x0a, 0x00, 0x00, 0x01, 0xff, 0x01, 0x30,
-    0x39, 0x00, 0x00 };
+    0x0c, 0x00, 0x05, 0x00, 0x05, 0x01, 0x00, 0x02, 0x80, 0x64 };
 
 static struct test_tlv _pkttlvs[] = {
   { .type = 1 },
+  { .type = 2, .exttype = 100 },
 };
 
-static uint8_t _originator[] = { 10, 0, 0, 1 };
-
-static struct test_message _msgs[] = {
-  {
-    .type = 1,
-    .addrlen = 4,
-  },
-  {
-    .type = 2,
-    .addrlen = 4,
-    .flags = 240,
-    .has_originator = true,
-    .originator = _originator,
-    .has_hopcount = true,
-    .hopcount = 1,
-    .has_hoplimit = true,
-    .hoplimit = 255,
-    .has_seqno = true,
-    .seqno = 12345,
-  },
-};
-
-static struct test_packet test12 = {
-  .test = "Interop 2010 Test 12",
+static struct test_packet test5 = {
+  .test = "Interop 2010 Test 05",
   .binary = _binary,
   .binlen = ARRAYSIZE(_binary),
 
@@ -89,13 +67,10 @@ static struct test_packet test12 = {
   .flags = 0x0c,
 
   .has_seq = true,
-  .seqno = 12,
+  .seqno = 5,
 
   .tlv_count = ARRAYSIZE(_pkttlvs),
   .tlvs = _pkttlvs,
-
-  .msg_count = ARRAYSIZE(_msgs),
-  .msgs = _msgs,
 };
 
-ADD_TEST(test12)
+ADD_TEST(test5)
